@@ -1,22 +1,15 @@
 package Module::Starter::Plugin::Template;
+# vi:et:sw=4 ts=4
+
+our $VERSION = '0.01';
 
 use warnings;
 use strict;
-use Carp qw( confess );
 
 =head1 NAME
 
 Module::Starter::Plugin::Template - module starter with templates
 
-=head1 VERSION
-
-Version 1.71_01
-
-=cut
-
-our $VERSION = '1.71_01';
-$VERSION = eval $VERSION;
-
 =head1 SYNOPSIS
 
  use Module::Starter qw(
@@ -31,7 +24,7 @@ $VERSION = eval $VERSION;
 This plugin is designed to be added to a Module::Starter::Simple-compatible
 Module::Starter class.  It adds stub methods for template retrieval and
 rendering, and it replaces all of Simple's _guts methods with methods that will
-retrieve and render the appropriate templates.
+retrieve and render the apropriate templates.
 
 =head1 CLASS METHODS
 
@@ -47,7 +40,7 @@ sub new {
     my $self  = $class->SUPER::new(@_);
     $self->{templates} = { $self->templates };
     $self->{renderer} = $self->renderer;
-    return bless $self => $class;
+    bless $self => $class;
 }
 
 =head1 OBJECT METHODS
@@ -56,13 +49,13 @@ sub new {
 
 This method is used to initialize the template store on the Module::Starter
 object.  It returns a hash of templates; each key is a filename and each value
-is the body of the template.  The filename F<Module.pm> is used for the module
+is the body of the template.  The filename "Module.pm" is used for the module
 template.
 
 =cut
 
 sub templates {
-    confess 'attempted to use abstract base templates method';
+    die "attempted to use abstract base templates method";
 }
 
 =head2 C<< renderer() >>
@@ -73,7 +66,7 @@ in the object's C<renderer> entry.  The implementation will determine its use.
 =cut
 
 sub renderer {
-    confess 'attempted to use abstract base renderer method';
+    die "attempted to use abstract base renderer method";
 }
 
 =head2 C<< render($template, \%options) >>
@@ -88,7 +81,7 @@ sub render {
     my $template = shift;
     my $options = shift;
 
-    confess 'attempted to use abstract base render method';
+    die "attempted to use abstract base render method";
 }
 
 =head2 _guts methods
@@ -136,19 +129,6 @@ sub Makefile_PL_guts {
     $self->render($template, \%options);
 }
 
-=item MI_Makefile_PL_guts
-
-=cut
-
-sub MI_Makefile_PL_guts {
-    my $self = shift;
-    my %options;
-    @options{qw(main_module main_pm_file)} = @_;
-
-    my $template = $self->{templates}{'MI_Makefile.PL'};
-    $self->render($template, \%options);
-}
-
 =item Build_PL_guts
 
 =cut
@@ -197,7 +177,7 @@ sub t_guts {
 
     my %t_files;
 
-    foreach (grep { /\.t$/ } keys %{$self->{templates}}) {
+    foreach (grep /\.t$/, keys %{$self->{templates}}) {
         my $template = $self->{templates}{$_};
         $t_files{$_} = $self->render($template, \%options);
     }
@@ -218,14 +198,14 @@ sub MANIFEST_guts {
     $self->render($template, \%options);
 }
 
-=item ignores_guts
+=item item cvsignore_guts
 
 =cut
 
-sub ignores_guts {
+sub cvsignore_guts {
     my $self = shift;
 
-    my $template = $self->{templates}{ignores};
+    my $template = $self->{templates}{cvsignore};
     $self->render($template);
 }
 
@@ -233,24 +213,22 @@ sub ignores_guts {
 
 =head1 AUTHOR
 
-Ricardo SIGNES, C<< <rjbs at cpan.org> >>
+Ricardo SIGNES, C<< <rjbs@cpan.org> >>
 
 =head1 Bugs
 
-Please report any bugs or feature requests to the bugtracker for this project
-on GitHub at: L<https://github.com/xsawyerx/module-starter/issues>. I will be
-notified, and then you'll automatically be notified of progress on your bug
-as I make changes.
+Please report any bugs or feature requests to
+C<bug-module-starter@rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org>.  I will be notified, and then you'll automatically be
+notified of progress on your bug as I make changes.
 
 =head1 COPYRIGHT
 
-Copyright 2005-2007 Ricardo SIGNES, All Rights Reserved.
+Copyright 2004 Ricardo SIGNES, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
 
-# vi:et:sw=4 ts=4
-
 1;
